---
# SPDX-FileCopyrightText: 2024 Nicco Kunzmann and Open Web Calendar Contributors <https://open-web-calendar.quelltext.eu/>
#
# SPDX-License-Identifier: CC-BY-SA-4.0

comments: false
title: Customize Your Own Online Calendar Display
description: "See the features or try the Open Web Calendar yourself!"
---

![](/assets/img/logo/github-social-preview.svg)

A highly flexible calendar display for your website.

Give a calendar your personal touch within minutes!

- **[Try it out now!]({{link.web}})**
- [See Examples](templates)

| Features |  |
| --- | --- |
| Instant Event Syncing | <center>✔</center> |
| Embed with an HTML snippet | <center>✔</center> |
| Desktop and Mobile | <center>✔</center> |
| Multi-Language Support | <center>✔</center> |
| Fixed and Automatic Timezone | <center>✔</center> |
| Easy Editing | <center>✔</center> |
| Designs To Choose  | <center>✔</center> |
| Multiple Calendar Sources | <center>✔</center> |
| Style per Calendar, Category and more | <center>✔</center> |
| Custom CSS | <center>✔</center> |
| Day, Week, Month, Agenda | <center>✔</center> |
| Work Week | <center>✔</center> |
| Custom Date & Time Range | <center>✔</center> |
| Custom Title & Icon | <center>✔</center> |
| Click on Event Location | <center>✔</center> |
| Styled Event Descriptions | <center>✔</center> |
| FOSS - No Vendor Lock-In | <center>✔</center> |
| [Hosted]({{link.web}}) and [Self-Hosted](host/self) | <center>✔</center> |
| Subscribe Link | <center>✔</center> |
| Community and Paid Support | <center>✔</center> |
| [Developer API](dev/api) | <center>✔</center> |
